import React, { useState, useEffect } from "react";
import AppBar from "@mui/material/AppBar";
import Toolbar from "@mui/material/Toolbar";
import Button from "@mui/material/Button";
import IconButton from "@mui/material/IconButton";
import Box from "@mui/material/Box";
import Header from "../Header";
import SearchIcon from "@mui/icons-material/Search";
import LocalMallIcon from '@mui/icons-material/LocalMall';
import AccountCircleIcon from "@mui/icons-material/AccountCircle";
import logoSrc from "../../assets/svg/logo.svg";
import { styled } from '@mui/material/styles';
import { MenuItem, Select, FormControl, Badge } from '@mui/material';
import MobileNav from "./components/MobileNav";
import MenuIcon from "@mui/icons-material/Menu";
import CategoryIcon from '@mui/icons-material/Category';
import HomeIcon from '@mui/icons-material/Home';
import BrushIcon from '@mui/icons-material/Brush';
import LoyaltyIcon from '@mui/icons-material/Loyalty';

const LanguageSelect = styled(Select)(({ theme }) => ({
  backgroundColor: 'black',
  color: 'white',
  border: '1px solid black',
  fontSize: 12,
  '& .MuiSelect-icon': {
    color: 'white',
  },
  '&:hover': {
    backgroundColor: 'white',
    color: 'black',
  },
  '& .MuiMenuItem-root': {
    backgroundColor: 'black',
    color: 'white',
  },
  '& .MuiMenuItem-root:hover': {
    backgroundColor: 'white',
    color: 'black',
  },
}));

const LanguageSelectItem = styled(MenuItem)(() => ({
  backgroundColor: 'black',
  color: 'white',
  '&:hover': {
    backgroundColor: 'white',
    color: 'black',
  },
}));


const Navbar = () => {

  const [showHeader, setShowHeader] = useState(true);
  const [lastScrollPos, setLastScrollPos] = useState(0);
  const [language, setLanguage] = useState('English');

  const [open, setOpen] = React.useState(false);

  const navItem = [
    {
      title: "DISCOVER",
      link: "/products",
      icon: <CategoryIcon />
    },
    {
      title: "HOME",
      link: "/",
      icon: <HomeIcon />
    },
    {
      title: "BEAUTY",
      link: "/products",
      icon: <BrushIcon />
    },
    {
      title: "SALE",
      link: "/products",
      icon: <LoyaltyIcon />
    }
  ]

  const handleChange = (event) => {
    setLanguage(event.target.value);
  };

  useEffect(() => {
    const handleScroll = () => {
      const currentScrollPos = window.scrollY;

      if (currentScrollPos > lastScrollPos && currentScrollPos > 50) setShowHeader(false)
      else setShowHeader(true)

      setLastScrollPos(currentScrollPos);
    };

    window.addEventListener("scroll", handleScroll);

    return () => {
      window.removeEventListener("scroll", handleScroll);
    };
  }, [lastScrollPos]);

  return (
    <>
      <AppBar position="fixed"
        sx={{
          backgroundColor: {
            xs: showHeader ? "rgba(0,0,0,0)" : "background.black",// somehow the logic for scrolling header is the same so I just gonna use showHeader state
            md: "rgba(0,0,0,0.9)", 
            lg: "background.black"
          },
          boxShadow: {
            xs: "none",
            md: "none",
            lg: "0px 2px 4px -1px rgba(0,0,0,0.2),0px 4px 5px 0px rgba(0,0,0,0.14),0px 1px 10px 0px rgba(0,0,0,0.12)"
          }
        }}
      >

        {/* Conditionally render the Header */}
        {showHeader && <Header />}

        <Toolbar sx={{
          px: {
            xs: 2,
            md: 10,
            lg: 20
          },
          py: 0.5
        }} disableGutters>

          {/* Left Section: Logo */}
          <Box sx={{
            display: {
              xs: "none",
              md: "none",
              lg: "block"
            }
          }}>
            <img src={logoSrc} alt="Logo"
              style={{
                width: 150,
                height: 50,
              }} />
          </Box>

          {/* SIDEBAR BUTTON */}
          <Box sx={{
            display: {
              xs: "block",
              md: "block",
              lg: "none"
            }
          }}>

            <IconButton
              onClick={() => setOpen(true)}
              sx={{
                backgroundColor: "transparent",
                color: "white",
                "&:hover": {
                  backgroundColor: "rgba(0, 0, 0, 0.1)",
                },
              }}
            >
              <MenuIcon fontSize="large" />
            </IconButton>

          </Box>

          {/* Center Section: Nav Items */}
          <Box
            sx={{
              flexGrow: 1,
              display: {
                xs: "none",
                md: "none",
                lg: "flex"
              },
              gap: 2,
            }}
          >

            {navItem.map(({ title, link }) => (<Button
              color="inherit"
              onClick={() => {
                window.location.href = link;
              }}
            >
              {title}
            </Button>))}

          </Box>

          {/* Right Section: Search and Profile */}
          <Box sx={{ display: "flex", alignItems: "center", gap: 1.2, ml: "auto" }}>

            <FormControl
              sx={{
                display: {
                  xs: "none",
                  lg: "block"
                }
              }}
            >
              <LanguageSelect
                value={language}
                onChange={handleChange}
                label=""
                MenuProps={{
                  PaperProps: {
                    style: {
                      backgroundColor: 'black',
                      color: 'white'
                    },
                  },
                }}
              >
                <LanguageSelectItem value="English">English</LanguageSelectItem>
                <LanguageSelectItem value="Malay">Malay</LanguageSelectItem>
                <LanguageSelectItem value="Chinese">Chinese</LanguageSelectItem>
              </LanguageSelect>
            </FormControl>

            <IconButton color="inherit">
              <SearchIcon sx={{ color: "white" }} />
            </IconButton>

            <Badge badgeContent={1} color="primary">
              <LocalMallIcon color="action" sx={{ color: "white" }} />
            </Badge>

            <IconButton color="inherit">
              <AccountCircleIcon sx={{ color: "white" }} />
            </IconButton>
          </Box>

        </Toolbar>
      </AppBar>

      <MobileNav open={open} menu={navItem} onClose={()=>{setOpen(false)}} />
    </>
  );
};

export default Navbar;
