import { useState } from "react";
import { useSelector } from "react-redux";
import {
  Box,
  Typography,
  Button,
  TextField
} from "@mui/material";
import AddIcon from '@mui/icons-material/Add';
import RemoveIcon from '@mui/icons-material/Remove';

const ProductDetails = () => {

  const product = useSelector((state) => state.products.product.data)
  const [quantity, setQuantity] = useState(1);
  const [selectedSize, setSelectedSize] = useState(null);

  const handleIncrement = () => {
    setQuantity((prevQuantity) => prevQuantity + 1);
  };

  const handleDecrement = () => {
    setQuantity((prevQuantity) => (prevQuantity > 1 ? prevQuantity - 1 : 1));
  };

  const handleSizeClick = (size) => {
    setSelectedSize(size);
    // alert(`Selected size: ${size}`);
  };

  return (
    <Box sx={{ position: "relative" }}>
      {/* Flex Container */}
      <Box sx={{ display: "flex", flexDirection: "column", gap: 2 }}>
        {/* Section 1: Product Info */}
        <Box>
          <Typography variant="h5" sx={{ fontWeight: "bold", mb: 2 }}>
            {product.title}
          </Typography>
          <Typography variant="body2" color="text.secondary">
            {product?.collections?.nodes[0]?.title}
          </Typography>
          <Typography
            variant="body1"
            sx={{ fontWeight: "bold" }}
          >
            {`${product?.compareAtPriceRange?.minVariantPrice?.currencyCode} 
            ${parseFloat(product?.compareAtPriceRange?.minVariantPrice?.amount).toFixed(2)}`}
          </Typography>
        </Box>

        {/* Section 2: Size */}
        <Box>
          <Typography variant="body1" sx={{ fontWeight: "bold", color: "#000", mb: 2 }}>
            Size
          </Typography>
          <Box display="flex" gap={2}>
            {["S", "M", "L", "XL"].map((size) => (
              <Button
                key={size}
                variant={selectedSize === size ? "contained" : "outlined"}
                color={selectedSize === size ? "primary" : "primary"}
                sx={{ color: "#000" }}
                onClick={() => handleSizeClick(size)}
              >
                {size}
              </Button>
            ))}
          </Box>
        </Box>


        {/* Section 3: Quantity */}
        <Box sx={{ mb: 5 }}>
          <Typography variant="body1" sx={{ fontWeight: "bold", color: "#000", mb: 2 }}>
            Qunatity
          </Typography>
          <Box display="flex" alignItems="center" gap={2}>
            <Button
              variant="contained"
              color="primary"
              sx={{width:"35px"}}
              onClick={handleDecrement}
            >
              <RemoveIcon />
            </Button>

            <TextField
              value={quantity}
              inputProps={{ readOnly: true, style: { textAlign: 'center' } }}
              size="small"
              sx={{width:"100px"}}
              variant="outlined"
            />

            <Button
              variant="contained"
              color="primary"
              sx={{width:"35px"}}
              onClick={handleIncrement}
            >
              <AddIcon />
            </Button>
          </Box>
        </Box>

        {/* Section 4: Description */}
        <Box sx={{ mb: 5 }}>
          <Typography variant="body1" sx={{ fontWeight: "bold", color: "#000" }}>
            Description
          </Typography>
          <Typography variant="body1" color="text.secondary" sx={{ fontWeight: "400" }}>
            <div dangerouslySetInnerHTML={{ __html: product.descriptionHtml }}></div>
          </Typography>
        </Box>

        <Button
          onClick={() => { window.location.href = "/cart" }}
          variant="contained"
          color="common.black"
          fullWidth
          sx={{
            backgroundColor: (theme) => theme.palette.common.black,
            color: "white",
            textTransform: "none",
            mt: 2,
            "&:hover": {
              backgroundColor: (theme) => theme.palette.grey[900],
            },
          }}
        >
          BUY NOW
        </Button>
      </Box>

    </Box>
  );
};

export default ProductDetails;
