import { createStorefrontApiClient } from '@shopify/storefront-api-client';
import { REACT_APP_ACCESS_TOKEN, REACT_APP_SHOP_NAME } from '../utils/httpCommon'

const defaultQuery = 'status:active, product_type:clothing, product_categroy:dresses';
const defaultResult = 10;
const defaultSortBy = 'TITLE';

const client = createStorefrontApiClient({
  storeDomain: `https://${REACT_APP_SHOP_NAME}/api/2024-10/graphql.json`,
  apiVersion: '2024-10',
  publicAccessToken: REACT_APP_ACCESS_TOKEN,
});

// getProduct(5, CREATED_AT, 'product_type:clothing'); 
const getProducts = async (maxResults = defaultResult, sortBy = defaultSortBy, customQuery = defaultQuery) => {

  const query = `{
    products(first: ${maxResults}, query: "${customQuery}", sortKey: ${sortBy}) {
      nodes {
        id
        title
        productType
        compareAtPriceRange {
          maxVariantPrice {
            amount
            currencyCode
          }
          minVariantPrice {
            amount
            currencyCode
          }
        }
        images(first: 1) {
          nodes {
            src
            url
          }
        }
        collections(first: 1) {
          nodes {
            title
          }
        }
        variants(first: 5) {
          nodes {
            id
            title
            price {
              amount
              currencyCode
            }
          }
        }
      }
      pageInfo {
        hasNextPage
        hasPreviousPage
      }
    }
  }`

  const { data, errors, extensions } = await client.request(query, {
    variables: {
      handle: 'sample-product',
    },
  });

  return data.products.nodes

}

const getProduct = async (id = "") => {

  const query = `{
    product(id: "gid://shopify/Product/${id}") {
      id
      title
      descriptionHtml
      productType
      compareAtPriceRange {
        maxVariantPrice {
          currencyCode
          amount
        }
        minVariantPrice {
          amount
          currencyCode
        }
      }
      images(first: 4) {
        nodes {
          src
          url
        }
      }
      variants(first: 5) {
        nodes {
          id
          title
          price {
            amount
            currencyCode
          }
        }
      }
      collections(first: 1) {
        nodes {
          title
        }
      }
    }
  }`

  const { data, errors, extensions } = await client.request(query, {
    variables: {
      handle: 'sample-product',
    },
  });

  return data.product

}


const ProductService = {
  getProducts,
  getProduct
}

export default ProductService
